AutoArchive._application — AutoArchive Developer Manual (ver. 1.2.1)

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »
- AutoArchive »

# AutoArchive._application

Application logic.

Provides the core functionality of the application.

## Sub-Packages

- AutoArchive._application.archiving

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »
- AutoArchive »